@@ -36,7 +36,7 @@ require_once 'model/Attachment.php';
 require_once 'model/QueryResult.php';
 require_once 'model/License.php';
 
-class Backend
+class Backend implements Serializable
 {
 
     var $base_url;
@@ -57,6 +57,32 @@ class Backend
     }
 
 
+
+    public function serialize()
+    {
+        $odata['base_url']        = $this->base_url;
+        $odata['filter']          = $this->filter;
+        $odata['rest_pass']       = $this->rest_pass;
+        $odata['rest_ssl_verify'] = $this->rest_ssl_verify;
+        $odata['rest_user']       = $this->rest_user;
+
+        return serialize($odata);
+    }
+
+
+    public function unserialize($sdata)
+    {
+        $odata = unserialize($sdata);
+        $this->base_url         = $odata['base_url'];
+        $this->filter           = $odata['filter'];
+        $this->rest_pass        = $odata['rest_pass'];
+        $this->rest_ssl_verify  = $odata['rest_ssl_verify'];
+        $this->rest_user        = $odata['rest_user'];
+
+        $this->_curl = curl_init();
+    }
+
+
     /**
      * Fetch one email from backend
      *
@@ -71,7 +97,7 @@ class Backend
         $App->log("Fetch mail from archive: $bennoId",3,'Backend');
 
         $request_url  = $this->base_url.'/mail/';
-        list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
+        @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
         $query_string = 'archive='.$archive.
                         '&id='.$bennoId;
         if ($scid)  $query_string .= '&scid='.$scid;
@@ -107,7 +133,7 @@ class Backend
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
         $request_url  = $this->base_url.'/mail/';
-        list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
+        @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
         $query_string = 'archive='.$archive.
                         '&id='.$bennoId.
                         '&format=headers';
@@ -131,7 +157,7 @@ class Backend
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
         $request_url  = $this->base_url.'/mail/';
-        list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
+        @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
         $query_string = 'archive='.$archive.
                         '&id='.$bennoId.
                         '&format=raw';
@@ -159,7 +185,7 @@ class Backend
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
         $request_url  = $this->base_url.'/attachment/';
-        list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
+        @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
         $query_string = 'archive='.$archive.
                         '&id='.$bennoId.
                         '&attachment='.$filename;
@@ -220,7 +246,7 @@ class Backend
 
         $query = $Query->getQuery();
         $request_url  = $this->base_url.'/search/';
-        list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
+        @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);  // scid: optional extension of name
         $query_string = 'archive='.$archive .
                  '&filterQuery='.$this->filter .
                  '&limit='.$limit .
@@ -358,19 +384,26 @@ class Backend
 
         // split header / body
         list($response_headers, $response_body) = explode("\r\n\r\n", $response, 2);
+
+        if (!$response_body) {
+            // empty body (logout,...) 
+            $App->log('Empty response from backend',4,'Backend');
+            return '';
+        }
+
         if ($format == 'raw') {
             $result = $response_body;
         }
         else {
-            if ( !mb_check_encoding($response_body, 'UTF-8') )
+            if (!mb_check_encoding($response_body, 'UTF-8') ) {
                 $response_body = mb_convert_encoding($response_body, 'UTF-8');
-
+            }
             $result = json_decode($response_body, true);
-        }
 
-        if (@array_key_exists('error',$result)) {
-            $App->log('[Backend/query] '.$result['error']);
-            throw new Exception($result['error']);
+            if (array_key_exists('error',$result)) {
+                $App->log('[Backend/query] '.$result['error']);
+                throw new Exception($result['error']);
+            }
         }
 
         return $result;
